@@ -1,12 +1,10 @@
-from .middleware import add_exception_diagnoser
 from .diagnoser import LLMExceptionDiagnoser
 from .settings import get_settings, Settings
 
 __all__ = [
-    "add_exception_diagnoser",
     "LLMExceptionDiagnoser",
     "get_settings",
     "Settings"
 ]
 
-__version__ = "0.2.3"
\ No newline at end of file
+__version__ = "0.3.1"
\ No newline at end of file
